==> activity-center-biz-1.0.2-20160622.061036-30-sources.jar: cn/com/duiba/activity/center/biz/remoteservice/impl/seconds_kill/RemoteDuibaSecondsKillActivityBrickServiceImpl.java <==
package cn.com.duiba.activity.center.biz.remoteservice.impl.seconds_kill;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.seconds_kill.DuibaSecondsKillActivityBrickDto;
import cn.com.duiba.activity.center.api.remoteservice.seconds_kill.RemoteDuibaSecondsKillActivityBrickService;
import cn.com.duiba.activity.center.biz.service.seconds_kill.DuibaSecondsKillActivityBrickService;

@Service
public class RemoteDuibaSecondsKillActivityBrickServiceImpl implements
		RemoteDuibaSecondsKillActivityBrickService {
	@Autowired
	private DuibaSecondsKillActivityBrickService duibaSecondsKillActivityBrickService;

	@Override
	public List<DuibaSecondsKillActivityBrickDto> findPage(
			Map<String, Object> paramMap) {
		return duibaSecondsKillActivityBrickService.findPage(paramMap);
	}

	@Override
	public Long findPageCount() {
		return duibaSecondsKillActivityBrickService.findPageCount();
	}

	@Override
	public DuibaSecondsKillActivityBrickDto find(Long id) {
		return duibaSecondsKillActivityBrickService.find(id);
	}

	@Override
	public void insert(
			DuibaSecondsKillActivityBrickDto duibaSecondsKillActivityBrick) {
		duibaSecondsKillActivityBrickService.insert(duibaSecondsKillActivityBrick);
	}

	@Override
	public void update(
			DuibaSecondsKillActivityBrickDto duibaSecondsKillActivityBrick) {
		duibaSecondsKillActivityBrickService.update(duibaSecondsKillActivityBrick);
	}

	@Override
	public void open(Long id) {
		duibaSecondsKillActivityBrickService.open(id);
	}

	@Override
	public void disable(Long id) {
		duibaSecondsKillActivityBrickService.disable(id);
	}

	@Override
	public DuibaSecondsKillActivityBrickDto findByTitle(String title) {
		return duibaSecondsKillActivityBrickService.findByTitle(title);
	}

	@Override
	public List<DuibaSecondsKillActivityBrickDto> findAllEnable() {
		return duibaSecondsKillActivityBrickService.findAllEnable();
	}

}

==> activity-center-biz-1.0.2-20160706.034119-56-sources.jar: cn/com/duiba/activity/center/biz/remoteservice/impl/seconds_kill/RemoteDuibaSecondsKillActivityBrickServiceImpl.java <==
package cn.com.duiba.activity.center.biz.remoteservice.impl.seconds_kill;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.seconds_kill.DuibaSecondsKillActivityBrickDto;
import cn.com.duiba.activity.center.api.remoteservice.seconds_kill.RemoteDuibaSecondsKillActivityBrickService;
import cn.com.duiba.activity.center.biz.service.seconds_kill.DuibaSecondsKillActivityBrickService;

@Service
public class RemoteDuibaSecondsKillActivityBrickServiceImpl implements
		RemoteDuibaSecondsKillActivityBrickService {
	@Autowired
	private DuibaSecondsKillActivityBrickService duibaSecondsKillActivityBrickService;

	@Override
	public List<DuibaSecondsKillActivityBrickDto> findPage(
			Map<String, Object> paramMap) {
		return duibaSecondsKillActivityBrickService.findPage(paramMap);
	}

	@Override
	public Long findPageCount() {
		return duibaSecondsKillActivityBrickService.findPageCount();
	}

	@Override
	public DuibaSecondsKillActivityBrickDto find(Long id) {
		return duibaSecondsKillActivityBrickService.find(id);
	}

	@Override
	public DuibaSecondsKillActivityBrickDto insert(DuibaSecondsKillActivityBrickDto duibaSecondsKillActivityBrick) {
		duibaSecondsKillActivityBrickService.insert(duibaSecondsKillActivityBrick);
		return duibaSecondsKillActivityBrick;
	}

	@Override
	public void update(
			DuibaSecondsKillActivityBrickDto duibaSecondsKillActivityBrick) {
		duibaSecondsKillActivityBrickService.update(duibaSecondsKillActivityBrick);
	}

	@Override
	public void open(Long id) {
		duibaSecondsKillActivityBrickService.open(id);
	}

	@Override
	public void disable(Long id) {
		duibaSecondsKillActivityBrickService.disable(id);
	}

	@Override
	public DuibaSecondsKillActivityBrickDto findByTitle(String title) {
		return duibaSecondsKillActivityBrickService.findByTitle(title);
	}

	@Override
	public List<DuibaSecondsKillActivityBrickDto> findAllEnable() {
		return duibaSecondsKillActivityBrickService.findAllEnable();
	}

}
